@@ -11,7 +11,8 @@ loglikGmrfOneRange = function(
       conditionalVariance=1),
     adjustEdges=adjustEdges)
   
-  fromC = .Call('gmrfLik',
+  fromC = .Call(
+    C_gmrfLik,
     Q, 
     obsCov, 
     as.double(xisqTausq), 
@@ -462,7 +463,8 @@ loglikGmrf = function(
           conditionalVariance=1),
         adjustEdges=adjustEdges)
       
-      fromC = .Call('gmrfLik',
+      fromC = .Call(
+        C_gmrfLik,
         Q, 
         obsCov, 
         as.double(xisqTausq), 
